searchData={"items":[{"type":"module","title":"Shorthand","doc":"Convenience macros to eliminate laborious typing. Provides macros for short map, string keyed map, keyword lists, and structs (ES6 like style)","ref":"Shorthand.html"},{"type":"module","title":"Examples: - Shorthand","doc":"These examples use variable arguments (default is 10, see configuration below)\n\nInstead of `%{one: one, two: two, three: three}`, you can type `m(one, two, three)`\n\nInstead of `my_func(one: one, two: two, three: three)`, you can type `my_func(kw(one, two, three))`\n\nInstead of `%MyStruct(one: one, two: two, three: three)`, you can type `st(MyStruct, one, two, three)`","ref":"Shorthand.html#module-examples"},{"type":"module","title":"Without variable arguemnts, - Shorthand","doc":"Instead of `%{one: one, two: two, three: three}`, you can type `m([one, two, three])`\n\nInstead of `my_func(one: one, two: two, three: three)`, you can type `my_func(kw([one, two, three]))`\n\nInstead of `%MyStruct(one: one, two: two, three: three)`, you can type `bulid_struct(MyStruct, [one, two, three])`","ref":"Shorthand.html#module-without-variable-arguemnts"},{"type":"module","title":"Configuration - Shorthand","doc":"For the convenience of `m(a, b, c, d, e, f, g, h, i, j)` instead of `m([a, b, c, d, e, f, g, h, i, j])` `Shorthand` generates multiple copies of each macro like m/1, m/2, m/3, …, m/10. You can configure how many of these \"variable argument\" macros are generated.\n\n    config :shorthand,\n      variable_args: 10 # false to remove variable arguemnts","ref":"Shorthand.html#module-configuration"},{"type":"module","title":"Usage - Shorthand","doc":"You can import the `Shorthand` module and call each macro\n\n    defmodule MyModule do\n      import Shorthand\n\n      def my_func(m(a, b)) do\n        kw(a, b)\n      end\n    end\n\nor you can require the module and prefix calls with the module name (example uses a module alias to keep the typing low\n\n    defmodule MyModule do\n      require Shorthand, as: S\n\n      def my_func(S.m(a, b)) do\n        S.kw(a, b)\n      end\n    end","ref":"Shorthand.html#module-usage"},{"type":"module","title":"Phoenix Examples - Shorthand","doc":"defmodule MyController do\n      # ...\n\n      def index(conn, sm(id)) do\n        model = Repo.get(MyModel, id)\n        # ...\n      end\n\n      def create(conn, sm(my_model: sm(first_name, last_name) = params)) do\n        changeset = MyModel.changeset(%MyModel{}, params) # params contains all form fields, not just first_name and last_name\n        # ...\n        conn\n        |> put_flash(:notice, \"User #{first_name} #{last_name} was created successfully\")\n        # ...\n      end\n    end","ref":"Shorthand.html#module-phoenix-examples"},{"type":"macro","title":"Shorthand.kw/1","doc":"Builds a keyword list where the keys and value arguments are the same name","ref":"Shorthand.html#kw/1"},{"type":"macro","title":"Example: - Shorthand.kw/1","doc":"iex> a = 1\n    iex> b = 2\n    iex> c = 3\n    iex> kw(a, b, c)\n    [a: 1, b: 2, c: 3]","ref":"Shorthand.html#kw/1-example"},{"type":"macro","title":"Examples - Shorthand.kw/1","doc":"iex> c = 3\n    iex> kw(a, _b, ^c) = [a: 1, b: 3, c: 3]\n    iex> a\n    1\n    iex> match?(kw(^a), [a: 1])\n    true","ref":"Shorthand.html#kw/1-examples"},{"type":"macro","title":"Shorthand.kw/2","doc":"","ref":"Shorthand.html#kw/2"},{"type":"macro","title":"Shorthand.kw/3","doc":"","ref":"Shorthand.html#kw/3"},{"type":"macro","title":"Shorthand.kw/4","doc":"","ref":"Shorthand.html#kw/4"},{"type":"macro","title":"Shorthand.kw/5","doc":"","ref":"Shorthand.html#kw/5"},{"type":"macro","title":"Shorthand.kw/6","doc":"","ref":"Shorthand.html#kw/6"},{"type":"macro","title":"Shorthand.kw/7","doc":"","ref":"Shorthand.html#kw/7"},{"type":"macro","title":"Shorthand.kw/8","doc":"","ref":"Shorthand.html#kw/8"},{"type":"macro","title":"Shorthand.kw/9","doc":"","ref":"Shorthand.html#kw/9"},{"type":"macro","title":"Shorthand.kw/10","doc":"","ref":"Shorthand.html#kw/10"},{"type":"macro","title":"Shorthand.m/1","doc":"Builds a map where the keys and values have the same name","ref":"Shorthand.html#m/1"},{"type":"macro","title":"Example: - Shorthand.m/1","doc":"iex> a = 1\n    iex> b = 2\n    iex> m(a, b)\n    %{a: 1, b: 2}","ref":"Shorthand.html#m/1-example"},{"type":"macro","title":"Example: - Shorthand.m/1","doc":"iex> a = 1\n    iex> c = 2\n    iex> m(a, b: m(c), d: nil)\n    %{a: 1, b: %{c: 2}, d: nil}","ref":"Shorthand.html#m/1-example"},{"type":"macro","title":"Example: - Shorthand.m/1","doc":"iex> a = 1\n    iex> m(^a, _b, c) = %{a: 1, b: 3, c: 2}\n    iex> c\n    2\n    iex> match?(m(^a), %{a: 2})\n    false","ref":"Shorthand.html#m/1-example"},{"type":"macro","title":"Example: - Shorthand.m/1","doc":"iex> m(model: m(a, b) = params) = %{model: %{a: 1, b: 2, c: 3, d: 4}}\n    iex> params\n    %{a: 1, b: 2, c: 3, d: 4}\n    iex> a\n    1\n    iex> b\n    2","ref":"Shorthand.html#m/1-example"},{"type":"macro","title":"Example: - Shorthand.m/1","doc":"iex> m(m(a, b) = model) = %{model: %{a: 1, b: 2, c: 3, d: 4}}\n    iex> model\n    %{a: 1, b: 2, c: 3, d: 4}\n    iex> a\n    1\n    iex> b\n    2","ref":"Shorthand.html#m/1-example"},{"type":"macro","title":"Shorthand.m/2","doc":"","ref":"Shorthand.html#m/2"},{"type":"macro","title":"Shorthand.m/3","doc":"","ref":"Shorthand.html#m/3"},{"type":"macro","title":"Shorthand.m/4","doc":"","ref":"Shorthand.html#m/4"},{"type":"macro","title":"Shorthand.m/5","doc":"","ref":"Shorthand.html#m/5"},{"type":"macro","title":"Shorthand.m/6","doc":"","ref":"Shorthand.html#m/6"},{"type":"macro","title":"Shorthand.m/7","doc":"","ref":"Shorthand.html#m/7"},{"type":"macro","title":"Shorthand.m/8","doc":"","ref":"Shorthand.html#m/8"},{"type":"macro","title":"Shorthand.m/9","doc":"","ref":"Shorthand.html#m/9"},{"type":"macro","title":"Shorthand.m/10","doc":"","ref":"Shorthand.html#m/10"},{"type":"macro","title":"Shorthand.sm/1","doc":"Builds a map where the string keys and values have the same name","ref":"Shorthand.html#sm/1"},{"type":"macro","title":"Example: - Shorthand.sm/1","doc":"iex> a = 1\n    iex> b = 2\n    iex> sm(a, b)\n    %{\"a\" => 1, \"b\" => 2}","ref":"Shorthand.html#sm/1-example"},{"type":"macro","title":"Example: - Shorthand.sm/1","doc":"iex> a = 1\n    iex> b = 2\n    iex> sm(a, other: sm(b))\n    %{\"a\" => 1, \"other\" => %{\"b\" => 2}}","ref":"Shorthand.html#sm/1-example"},{"type":"macro","title":"Example: - Shorthand.sm/1","doc":"iex> a = 1\n    iex> sm(^a, _b, c) = %{\"a\" => 1, \"b\" => 3, \"c\" => 2}\n    iex> c\n    2\n    iex> match?(sm(^a), %{\"a\" => 2})\n    false","ref":"Shorthand.html#sm/1-example"},{"type":"macro","title":"Example: - Shorthand.sm/1","doc":"iex> sm(model: sm(a, b) = params) = %{\"model\" => %{\"a\" => 1, \"b\" => 2, \"c\" => 3, \"d\" => 4}}\n    iex> params\n    %{\"a\" => 1, \"b\" => 2, \"c\" => 3, \"d\" => 4}\n    iex> a\n    1\n    iex> b\n    2","ref":"Shorthand.html#sm/1-example"},{"type":"macro","title":"Example: - Shorthand.sm/1","doc":"iex> sm(sm(a, b) = model) = %{\"model\" => %{\"a\" => 1, \"b\" => 2, \"c\" => 3, \"d\" => 4}}\n    iex> model\n    %{\"a\" => 1, \"b\" => 2, \"c\" => 3, \"d\" => 4}\n    iex> a\n    1\n    iex> b\n    2","ref":"Shorthand.html#sm/1-example"},{"type":"macro","title":"Shorthand.sm/2","doc":"","ref":"Shorthand.html#sm/2"},{"type":"macro","title":"Shorthand.sm/3","doc":"","ref":"Shorthand.html#sm/3"},{"type":"macro","title":"Shorthand.sm/4","doc":"","ref":"Shorthand.html#sm/4"},{"type":"macro","title":"Shorthand.sm/5","doc":"","ref":"Shorthand.html#sm/5"},{"type":"macro","title":"Shorthand.sm/6","doc":"","ref":"Shorthand.html#sm/6"},{"type":"macro","title":"Shorthand.sm/7","doc":"","ref":"Shorthand.html#sm/7"},{"type":"macro","title":"Shorthand.sm/8","doc":"","ref":"Shorthand.html#sm/8"},{"type":"macro","title":"Shorthand.sm/9","doc":"","ref":"Shorthand.html#sm/9"},{"type":"macro","title":"Shorthand.sm/10","doc":"","ref":"Shorthand.html#sm/10"},{"type":"macro","title":"Shorthand.st/2","doc":"Builds a struct where the field names are the same as the arguments supplied","ref":"Shorthand.html#st/2"},{"type":"macro","title":"Example: - Shorthand.st/2","doc":"iex> scheme = \"https\"\n    iex> host = \"elixir-lang.org\"\n    iex> path = \"/docs.html\"\n    iex> st(URI, scheme, host, path)\n    %URI{scheme: \"https\", host: \"elixir-lang.org\", path: \"/docs.html\"}","ref":"Shorthand.html#st/2-example"},{"type":"macro","title":"Shorthand.st/3","doc":"","ref":"Shorthand.html#st/3"},{"type":"macro","title":"Shorthand.st/4","doc":"","ref":"Shorthand.html#st/4"},{"type":"macro","title":"Shorthand.st/5","doc":"","ref":"Shorthand.html#st/5"},{"type":"macro","title":"Shorthand.st/6","doc":"","ref":"Shorthand.html#st/6"},{"type":"macro","title":"Shorthand.st/7","doc":"","ref":"Shorthand.html#st/7"},{"type":"macro","title":"Shorthand.st/8","doc":"","ref":"Shorthand.html#st/8"},{"type":"macro","title":"Shorthand.st/9","doc":"","ref":"Shorthand.html#st/9"},{"type":"macro","title":"Shorthand.st/10","doc":"","ref":"Shorthand.html#st/10"},{"type":"macro","title":"Shorthand.st/11","doc":"","ref":"Shorthand.html#st/11"},{"type":"extras","title":"Shorthand","doc":"# Shorthand\n\n![](https://github.com/andrewtimberlake/shorthand/actions/workflows/elixir.yml/badge.svg)\n\nShorthand provides macros to create or match against maps and keyword lists with atom or string-based keys.","ref":"readme.html"},{"type":"extras","title":"Installation - Shorthand","doc":"Add `shorthand` as a dependency in your project in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:shorthand, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Shorthand","doc":"Wherever you would use a map literal, you can use the shorthand macros instead, whether in assignment or as a pattern.\n\n`%{conn: conn}` can become `m(conn)`.\n\n`%{params: %{\"email\" => email, \"password\" => password}}` can become `m(params: sm(email, password))`.\n\n`%{foo: _foo}` can become `m(_foo)`.\n\n`%{foo: ^foo}` can become `m(^foo)`.\n\nYou can specify the variable name for the key you are destructuring along with shorthand keys, but like normal function calls, they work as keyword lists at the end.\n\n`%{foo: foo, bar: bor, baz: qux}` can become `m(foo, bar, baz: qux)`\n\n`%{foo: bar, baz: baz, qux: qux}` would need to become `m(baz, qux, foo: bar)`\n\nSee the [docs](https://hexdocs.pm/shorthand) for more examples","ref":"readme.html#usage"},{"type":"extras","title":"Atom keyed maps - Shorthand","doc":"| Shorthand                            | Equivalent Elixir                                         |\n| ------------------------------------ | --------------------------------------------------------- |\n| `m(foo, bar)`                        | `%{foo: foo, bar: bar}`                                   |\n| `m(foo, _bar, ^baz)`                 | `%{foo: foo, bar: _bar, baz: ^baz}`                       |\n| `m(foo, bar, baz: m(qux))`           | `%{foo: foo, bar: bar, baz: %{qux: qux}}`                 |\n| `m(foo, m(baz) = bar, qux: m(quux))` | `%{foo: foo, bar: %{baz: baz} = bar, qux: %{quux: quux}}` |\n| `m(foo, bar = m(baz), qux: m(quux))` | `%{foo: foo, bar: %{baz: baz} = bar, qux: %{quux: quux}}` |","ref":"readme.html#atom-keyed-maps"},{"type":"extras","title":"String keyed maps - Shorthand","doc":"| Shorthand                               | Equivalent Elixir                                                             |\n| --------------------------------------- | ----------------------------------------------------------------------------- |\n| `sm(foo, bar)`                          | `%{\"foo\" => foo, \"bar\" => bar}`                                               |\n| `sm(foo, _bar, ^baz)`                   | `%{\"foo\" => foo, \"bar\" => _bar, \"baz\" => ^baz}`                               |\n| `sm(foo, bar, baz: sm(qux))`            | `%{\"foo\" => foo, \"bar\" => bar, \"baz\" => %{\"qux\" => qux}}`                     |\n| `sm(foo, sm(baz) = bar, qux: sm(quux))` | `%{\"foo\" => foo, \"bar\" => %{\"baz\" => baz} = bar, \"qux\" => %{\"quux\" => quux}}` |\n| `sm(foo, bar = sm(baz), qux: sm(quux))` | `%{\"foo\" => foo, \"bar\" => %{\"baz\" => baz} = bar, \"qux\" => %{\"quux\" => quux}}` |","ref":"readme.html#string-keyed-maps"},{"type":"extras","title":"Keyword lists - Shorthand","doc":"| Shorthand                               | Equivalent Elixir                                      |\n| --------------------------------------- | ------------------------------------------------------ |\n| `kw(foo, bar)`                          | `[foo: foo, bar: bar]`                                 |\n| `kw(foo, _bar, ^baz)`                   | `[foo: foo, bar: _bar, baz: ^baz]`                     |\n| `kw(foo, bar, baz: kw(qux))`            | `[foo: foo, bar: bar, baz: [qux: qux]]`                |\n| `kw(foo, kw(baz) = bar, qux: kw(quux))` | `[foo: foo, bar: [baz: baz] = bar, qux: [quux: quux]]` |\n| `kw(foo, bar = kw(baz), qux: kw(quux))` | `[foo: foo, bar: [baz: baz] = bar, qux: [quux: quux]]` |","ref":"readme.html#keyword-lists"},{"type":"extras","title":"Structs - Shorthand","doc":"| Shorthand                | Equivalent Elixir               |\n| ------------------------ | ------------------------------- |\n| `st(MyStruct, foo, bar)` | `%MyStruct{foo: foo, bar: bar}` |","ref":"readme.html#structs"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}